"""
.. module:: pitching
   :platform: Unix, Windows
   :synopsis: Pitching module for sabermetrics package containing some functions related to pitching only.

.. moduleauthor:: Fernando Crema <fcremaldc@gmail.com>
"""


def era(er, outs):
    """Represents the number of earned runs a pitcher allows per nine innings -- with earned runs being any runs that
    scored without the aid of an error or a passed ball.
    :param er: Earned runs.
    :type er: int.
    :param outs: Number of batters and baserunners that are put out while the pitcher is on the mound.
    :type outs: int.
    :returns:  float -- the return code.
    :raises: ZeroDivisionError
    """

    try:
        return 27.0*er/outs
    except ZeroDivisionError:
        print("Outs must be greater than 0.")
        import sys
        sys.exit(-1)




"""Sabermetrics: A python package with a set of baseball analytic functions for sabermetric purposes.

.. moduleauthor:: Fernando Crema <fcremaldc@gmail.com>

"""

import sabermetrics.pitching
import sabermetrics.fielding
import sabermetrics.batting


def start():
    "Initializing modules."



"""
.. module:: batting
   :platform: Unix, Windows
   :synopsis: Batting module for sabermetrics package containing some functions related to batting only.

.. moduleauthor:: Fernando Crema <fcremaldc@gmail.com>
"""


def avg(h, ab):
    """batting average is determined by dividing a player's hits by his total at-bats for a number between zero
    (shown as .000) and one (1.000).
    :param h: Hits.
    :type h: int.
    :param ab: At bats.
    :type ab: int.
    :returns:  float -- The batting average.
    :raises: ZeroDivisionError
    """
    # TODO: Add innings option.
    try:
        return h*1.0/ab
    except ZeroDivisionError:
        print("At bats must be greater than 0.")
        import sys
        sys.exit(-1)


"""
.. module:: fielding
   :platform: Unix, Windows
   :synopsis: Fielding module for sabermetrics package containing some functions related to fielding only.

.. moduleauthor:: Fernando Crema <fcremaldc@gmail.com>
"""


def fpct(a, po, e):
    """How often does a fielder or team make the play when tasked with fielding a batted ball, throwing a ball,
     or receiving a thrown ball for an out.
    :param a: Assists.
    :type a: int.
    :param po: Putouts.
    :type po: int.
    :param e: Errors.
    :type e: int.
    :returns:  float -- The fielding percentage.
    :raises: ZeroDivisionError
    """

    try:
        return (po + a) * 1.0 / (po + a + e)
    except ZeroDivisionError:
        print("Total chances must be greater than 0.")
        import sys
        sys.exit(-1)


from distutils.core import setup
setup(
  name = 'sabermetrics',
  packages = ['sabermetrics'], 
  version = '0.1',
  description = 'Beta version of the Sabermetrics Package: A python package with a set of baseball analytic functions for sabermetric purposes.',
  author = 'Fernando Crema',
  author_email = 'fcremaldc@gmail.com',
  url = 'https://github.com/belgrades/sabermetrics', 
  download_url = 'https://github.com/belgrades/sabermetrics/tarball/0.1', 
  keywords = ['beta', 'sabermetrics', 'baseball', 'MLB'], 
  classifiers = [],
)
